/*
 * @(#)HashMap_1_1.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.compatibility;

import java.util.Enumeration;
import java.util.Hashtable;

/**
 * The Java 1.1 implementation of HashMap.
 * @version 1.0 2004.01.11
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
class HashMap_1_1 implements Map {

  /** The hash table. */
  protected Hashtable hashtable;

  /**
   * Constructs an empty HashMap with the default initial capacity (16) and the default load factor (0.75).
   */
  public HashMap_1_1() {
    hashtable = new Hashtable(16, 0.75f);
  }

  /**
   * Constructs an empty HashMap with the specified initial capacity and the default load factor (0.75).
   * @param initialCapacity The initial capacity.
   */
  public HashMap_1_1(int initialCapacity) {
    hashtable = new Hashtable(initialCapacity, 0.75f);
  }

  /**
   * Returns true if this map contains a mapping for the specified key. 
   * @param key The key.
   * @return True if found.
   */
  public boolean containsKey(Object key) {
    if(key == null) {
      key = Compatibility.NULL;
    }
    return hashtable.containsKey(key);
  }

  /**
   * Returns the value to which this map maps the specified key.
   * @param key The key.
   * @return The object.
   */
  public Object get(Object key) {
    if(key == null) {
      key = Compatibility.NULL;
    }
    Object value = hashtable.get(key);
    if(value == Compatibility.NULL) {
      return null;
    }
    return value;
  }

  /**
   * Associates the specified value with the specified key in this map (optional operation).
   * @param key The key.
   * @param value The value.
   * @return The previous value.
   */
  public Object put(Object key, Object value) {
    if(key == null) {
      key = Compatibility.NULL;
    }
    if(value == null) {
      value = Compatibility.NULL;
    }
    value = hashtable.put(key, value);
    if(value == Compatibility.NULL) {
      value = null;
    }
    return value;
  }

  /**
   * Returns a set view of the keys contained in this map.
   * @return The set.
   */
  public Set keySet() {
    Object[] objects = new Object[hashtable.size()];
    int i=0;
    for(Enumeration e = hashtable.keys(); e.hasMoreElements(); i++) {
      objects[i] = e.nextElement();
    }
    HashSet hashSet = new HashSet(objects.length);
    for(int j=0; j<objects.length; j++) {
      Object key = objects[j];
      if(key == Compatibility.NULL) {
        hashSet.add(null);
      } else {
        hashSet.add(key);
      }
    }
    return hashSet;
  }

}
