/*
 * @(#)SwingUtilities.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.compatibility;

import java.lang.reflect.InvocationTargetException;

/**
 * The SwingUtilities compatible version.
 * @version 1.0 2004.01.11
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class SwingUtilities {

  /**
   * Indicate if the current thread is the event dispatch thread.
   * @return True if the current thread is the dispatch thread.
   */
  public static boolean isEventDispatchThread() {
    if(Compatibility.isJava1_1()) {
      return SwingUtilities_1_1.isEventDispatchThread();
    }
    return javax.swing.SwingUtilities.isEventDispatchThread();
  }

  /**
   * Run a Runnable in the event dispatch thread, asynchronously.
   * @param runnable The action to run.
   */
  public static void invokeLater(Runnable runnable) {
    if(Compatibility.isJava1_1()) {
      SwingUtilities_1_1.invokeLater(runnable);
    } else {
      javax.swing.SwingUtilities.invokeLater(runnable);
    }
  }

  /**
   * Runs a Runnable in the dispatch thread.
   * @param runnable The action to run.
   * @throws InterruptedException If interrupted.
   * @throws InvocationTargetException If exception on target.
   */
  public static void invokeAndWait(final Runnable runnable) throws InterruptedException, InvocationTargetException {
    if(Compatibility.isJava1_1()) {
      SwingUtilities_1_1.invokeAndWait(runnable);
    } else {
      javax.swing.SwingUtilities.invokeAndWait(runnable);
    }
  }

}
