/*
 * @(#)NullComponentCreator.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.creator;

import java.awt.Component;
import java.awt.Container;
import java.awt.Panel;

import javax.swing.JComponent;
import javax.swing.JPanel;

import chrriis.uihierarchy.UIHConfig;
import chrriis.uihierarchy.compatibility.Compatibility;

/**
 * The component creator that handles the null object.
 * @version 1.0 2003.11.03
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class NullComponentCreator implements ComponentCreator {

  /**
   * Create a component from a null component. The resulting component is a
   * panel.
   * @param uihConfig The configuration in use.
   * @param parentContainer The container that will be the parent of the
   * component to create. The addition of the component to the parent will be
   * automatic so this method should not affect this behaviour. The parent can
   * be null when the node is a sub node.
   * @param component The component's representation from which to create the
   * component. It is ignored by this creator.
   * @param level The indication of the level of the component. It is either
   * <code>NODE</code> or <code>LEAF</code>. Root nodes are differentiated from
   * nodes by the fact that the parent container is null.
   * @return A panel.
   * @see chrriis.uihierarchy.creator.ComponentCreator#createComponent(chrriis.uihierarchy.UIHConfig, java.awt.Container, java.lang.Object, int)
   */
  public Component createComponent(UIHConfig uihConfig, Container parentContainer, Object component, int level) {
    if(Compatibility.isSwingPresent() && (parentContainer instanceof JComponent || (parentContainer == null && uihConfig.isSwingPreferred()))) {
      return new JPanel();
    }
    return new Panel();
  }

}
