/*
 * @(#)FlowHLayout.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.layout;

import java.awt.FlowLayout;
import java.awt.LayoutManager;

import chrriis.uihierarchy.UIHConfig;
import chrriis.uihierarchy.util.UnitParser;

/**
 * A flow layout that is lazily created, using the UIH configuration. This
 * allows the use of units to determine the gaps, which are defined as
 * <code>String</code>s.
 * @version 1.0 2005.02.06
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class FlowHLayout implements HLayoutManager {

  protected int align;
  protected String hgap;
  protected String vgap;

  /**
   * Constructs a new Flow Layout with a centered alignment and a default 5-unit horizontal and vertical gap.
   */
  public FlowHLayout() {
    this(FlowLayout.CENTER);
  }
  
  /**
   * Constructs a new Flow Layout with the specified alignment and a default 5-unit horizontal and vertical gap.
   * @param align
   */
  public FlowHLayout(int align) {
    this(align, "5", "5");
  }

  /**
   * Creates a new flow layout manager with the indicated alignment and the indicated horizontal and vertical gaps.
   * @param align
   * @param hgap
   * @param vgap
   */
  public FlowHLayout(int align, String hgap, String vgap) {
    this.align = align;
    this.hgap = hgap;
    this.vgap = vgap;
  }

  public LayoutManager createLayout(UIHConfig uihConfig) {
    int hgap = 0;
    if(this.hgap != null) {
      hgap = UnitParser.intPixelValue(uihConfig, this.hgap);
    }
    int vgap = 0;
    if(this.vgap != null) {
      vgap = UnitParser.intPixelValue(uihConfig, this.vgap);
    }
    return new FlowLayout(align, hgap, vgap);
  }

}
