/*
 * @(#)UnitParser.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.util;

import chrriis.uihierarchy.UIHConfig;
import chrriis.uihierarchy.unit.Pixel;
import chrriis.uihierarchy.unit.Unit;

/**
 * A utility class to parse and convert units from their string representations.
 * @version 1.0 2005.02.02
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class UnitParser {

  protected UnitParser() {}

  /**
   * Convert a string representation of a value with or without a unit
   * specification, into its pixel integer value.
   * @param unitValueRepresentation The value to convert, eventually defined in
   * a unit other than pixel.
   * @return The result of the conversion to the pixel value.
   */
  public static int intPixelValue(UIHConfig uihConfig, String unitValueRepresentation) {
    return (int)Math.round(doublePixelValue(uihConfig, unitValueRepresentation));
  }

  /**
   * Convert a string representation of a value with or without a unit
   * specification, into its pixel double value.
   * @param unitValueRepresentation The value to convert, eventually defined in
   * a unit other than pixel.
   * @return The result of the conversion to the pixel value.
   */
  public static double doublePixelValue(UIHConfig uihConfig, String unitValueRepresentation) {
    if(unitValueRepresentation == null) {
      throw new IllegalArgumentException("The representation of a unit cannot be null!");
    }
    unitValueRepresentation = unitValueRepresentation.trim();
    int index = unitValueRepresentation.length();
    for(; index > 0 && Character.isLetter(unitValueRepresentation.charAt(index - 1)); index--);
    String value = unitValueRepresentation.substring(0, index).trim();
    String unit = unitValueRepresentation.substring(index).trim();
    if("".equals(unit)) {
      return Double.parseDouble(value);
    }
    Unit sourceUnit = uihConfig.getUnit(unit);
    if(sourceUnit == null) {
      throw new IllegalArgumentException("The unit \""+ unit + "\" is not registered!");
    }
    if(sourceUnit instanceof Pixel.PixelUnit) {
      return Double.parseDouble(value);
    }
    return Pixel.doubleValue(sourceUnit, Double.parseDouble(value));
  }

}
