/*
 * @(#)MapComponentResolver.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.xml.resolver;

import java.util.Map;

/**
 * The component resolver for maps.
 * @version 1.0 2003.10.06
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class MapComponentResolver implements ComponentResolver {

  /** The map of components. */
  protected Map componentsMap;

  /**
   * Construct a component resolver for a map.
   * @param componentsMap The map where keys are the components names and the
   * values are the components themselves.
   */
  public MapComponentResolver(Map componentsMap) {
    this.componentsMap = componentsMap;
  }

  /**
   * Resolve a component from its name.
   * @param name The name of the component to resolve.
   * @see chrriis.uihierarchy.xml.resolver.ComponentResolver#resolve(java.lang.String)
   */
  public Object resolve(String name) {
    if(componentsMap == null) {
      return null;
    }
    return componentsMap.get(name);
  }

}
